import React, { useState, useEffect, useRef, useCallback } from "react";
import { Link, useParams } from "react-router-dom";
import axios from "axios";
import Button from "@material-ui/core/Button";
import { useNavigate } from "react-router-dom";
import { isAutheticated } from "src/auth";
import swal from "sweetalert";
import debounce from "lodash.debounce";
import Dialog from "@material-ui/core/Dialog";
import DialogActions from "@material-ui/core/DialogActions";
import DialogContent from "@material-ui/core/DialogContent";
import DialogTitle from "@material-ui/core/DialogTitle";
import TextField from "@material-ui/core/TextField";

const ViewSalesCoOrdinatorTM = () => {
  const token = isAutheticated();
  const { id } = useParams();
  const navigate = useNavigate();
  const [loading, setLoading] = useState(false);
  const [success, setSuccess] = useState(true);
  const [salescoordinatorsData, setSalesCoOrdinatorsData] = useState([]);
  const [data, setData] = useState({});
  const nameRef = useRef();
  const mobileRef = useRef();
  const scnameRef = useRef();
  const scmobileRef = useRef();

  const [currentPage, setCurrentPage] = useState(1);
  const [itemPerPage, setItemPerPage] = useState(10);
  const [modalcurrentPage, setmodalCurrentPage] = useState(1);
  const modalitemPerPage = 10;
  const [totalData, setTotalData] = useState(0);
  const [openModal, setOpenModal] = useState(false);
  const [modalSalesCoordinators, setModalSalesCoordinators] = useState([]);
  const [modalTotalData, setModalTotalData] = useState(0);

  // Fetch territory manager data
  useEffect(() => {
    axios
      .get(`/api/territorymanager/getOne/${id}`, {
        headers: { Authorization: `Bearer ${token}` },
      })
      .then((response) => setData(response.data.data))
      .catch((error) => console.error("Error fetching TM data:", error));
  }, [id, token]);

  // Fetch Sales Coordinators data
  const getTMsSalesCoOrdinatorsData = async () => {
    setLoading(true);
    axios
      .get(`/api/salescoordinator/getbyTmId/${id}`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
        params: {
          page: currentPage,
          show: itemPerPage,
          name: nameRef.current?.value,
          mobileNumber: mobileRef.current?.value,
        },
      })
      .then((res) => {
        // console.log(res.data.salesCoOrinators);
        setSalesCoOrdinatorsData(res.data?.salesCoOrinators);
        setTotalData(res.data?.total_data);
      })
      .catch((err) => {
        const msg = err?.response?.data?.message || "Something went wrong!";
        swal({
          title: "Error",
          text: msg,
          icon: "error",
          button: "Retry",
          dangerMode: true,
        });
      })
      .finally(() => setLoading(false));
  };

  useEffect(() => {
    getTMsSalesCoOrdinatorsData();
  }, [success, itemPerPage, currentPage]);

  // Debounced search for Sales Coordinators
  const debouncedSearch = useCallback(
    debounce(() => {
      setCurrentPage(1);
      getTMsSalesCoOrdinatorsData();
    }, 500),
    [currentPage, itemPerPage]
  );

  const handleSearchChange = useCallback(() => {
    debouncedSearch();
  }, [debouncedSearch]);
  // Fetch Sales Coordinators data for modal
  const getSalesCoOrdinatorsData = async () => {
    setLoading(true);
    try {
      const res = await axios.get(`/api/salescoordinator/getAll`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
        params: {
          page: modalcurrentPage,
          show: modalitemPerPage,
          name: scnameRef.current?.value,
          mobileNumber: scmobileRef.current?.value,
        },
      });
      setModalSalesCoordinators(res.data?.salesCoOrinators);
      setModalTotalData(res.data?.total_data);
    } catch (err) {
      const msg = err?.response?.data?.message || "Something went wrong!";
      swal({
        title: "Error",
        text: msg,
        icon: "error",
        button: "Retry",
        dangerMode: true,
      });
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    if (openModal) {
      getSalesCoOrdinatorsData();
    }
  }, [openModal, modalcurrentPage]);

  // Debounced search for Sales Coordinators in modal
  const debouncedmodalSearch = useCallback(
    debounce(() => {
      setmodalCurrentPage(1);
      getSalesCoOrdinatorsData();
    }, 500),
    [modalcurrentPage]
  );

  const handlemodalSearchChange = useCallback(() => {
    debouncedmodalSearch();
  }, [debouncedmodalSearch]);

  const handleOpenModal = () => {
    setOpenModal(true);
  };

  const handleCloseModal = () => {
    setOpenModal(false);
  };
  const handlePreviousPage = () => {
    if (modalcurrentPage > 1) {
      setmodalCurrentPage(modalcurrentPage - 1);
    }
  };
  
  const handleNextPage = () => {
    if (modalPrincipalDistributors.length === modalitemPerPage) {
      setmodalCurrentPage(modalcurrentPage + 1);
    }
  };
  const handleDelete = (id) => {
    swal({
      title: "Are you sure?",
      icon: "error",
      buttons: {
        Yes: { text: "Yes", value: true },
        Cancel: { text: "Cancel", value: "cancel" },
      },
    }).then((value) => {
      if (value === true) {
        axios
          .delete(`/api/salescoordinator/unmap/${id}`, {
            headers: {
              "Access-Control-Allow-Origin": "*",
              Authorization: `Bearer ${token}`,
            },
          })
          .then((res) => {
            swal({
              title: "Deleted",
              text: "SalesCoOrdinator Unmapped successfully!",
              icon: "success",
              button: "ok",
            });
            setSuccess((prev) => !prev);
          })
          .catch((err) => {
            let msg = err?.response?.data?.message
              ? err?.response?.data?.message
              : "Something went wrong!";
            swal({
              title: "Warning",
              text: msg,
              icon: "error",
              button: "Retry",
              dangerMode: true,
            });
          });
      }
    });
  };
  const handleAddSalesCoordinator = async (scid) => {
    try {
      await axios.put(
        `/api/salescoordinator/mappedtm/${scid}`,
        { mappedby: id },
        {
          headers: {
            Authorization: `Bearer ${token}`,
          },
        }
      );
      swal({
        title: "Success",
        text: "Sales Coordinator added successfully!",
        icon: "success",
        button: "Ok",
      });
      setSuccess((prev) => !prev);
      handleCloseModal(); // Close modal after adding
    } catch (err) {
      const msg = err?.response?.data?.message || "Something went wrong!";
      swal({
        title: "Error",
        text: msg,
        icon: "error",
        button: "Retry",
        dangerMode: true,
      });
    }
  };

  return (
    <div className="main-content">
      <div className="page-content">
        <div className="container-fluid">
          <div className="row">
            <div className="col-12">
              <div className="page-title-box d-flex mb-1 align-items-center justify-content-between">
                {/* Left Side with Information in Separate Columns */}
                <div className="d-flex flex-column">
                  <div style={{ fontSize: "18px" }} className="fw-bold">
                    Unique ID: {data?.uniqueId}
                  </div>
                  <div style={{ fontSize: "18px" }} className="fw-bold">
                    Name: {data?.name}
                  </div>
                  <div style={{ fontSize: "18px" }} className="fw-bold">
                    Mobile Number: {data?.mobileNumber}
                  </div>
                  <div style={{ fontSize: "18px" }} className="fw-bold">
                    Mail: {data?.email}
                  </div>
                </div>

                {/* Right Side with the Button */}
                <div className="page-title-right">
                  <Button
                    variant="contained"
                    color="primary"
                    style={{
                      fontWeight: "bold",
                      marginBottom: "1rem",
                      textTransform: "capitalize",
                    }}
                    onClick={handleOpenModal}
                  >
                    Add Sales Coordinator
                  </Button>
                  <Button
                    variant="contained"
                    color="secondary"
                    style={{
                      fontWeight: "bold",
                      marginBottom: "1rem",
                      marginLeft: "1rem",
                      textTransform: "capitalize",
                      backgroundColor: "#d32f2f", // Red color for danger
                      color: "#fff",
                      "&:hover": {
                        backgroundColor: "#b71c1c", // Darker red on hover
                      },
                    }}
                    onClick={() => navigate("/territorymanagers")}
                  >
                    Back
                  </Button>
                </div>
              </div>
              <Dialog open={openModal} onClose={handleCloseModal} maxWidth="md" fullWidth>
                <DialogTitle>Search and Add Sales Coordinator</DialogTitle>
                <DialogContent>
                  <TextField
                    label="Sales Coordinator Name"
                    placeholder="Sales Coordinator name"
                    inputRef={scnameRef}
                    onChange={handlemodalSearchChange}
                    disabled={loading}
                  />
                  <TextField
                    className="ml-4"
                    label="Mobile Number"
                    placeholder="Mobile Number"
                    inputRef={scmobileRef}
                    onChange={handlemodalSearchChange}
                    disabled={loading}
                  />

                  <div className="table-responsive table-shoot mt-3">
                    <table className="table table-centered table-nowrap">
                      <thead>
                        <tr>
                          <th>Id</th>
                          <th>Name</th>
                          <th>Mobile</th>
                          <th>TM</th>
                          <th>Action</th>
                        </tr>
                      </thead>
                      <tbody>
                        {modalSalesCoordinators.map((coordinator) => (
                          <tr key={coordinator._id}>
                            <td>{coordinator.uniqueId}</td>
                            <td>{coordinator.name}</td>
                            <td>{coordinator.mobileNumber}</td>
                            <td>{coordinator.mappedby?.name || "N/A"}</td>
                            <td>
                              <Button
                                variant="contained"
                                color="primary"
                                onClick={() =>
                                  handleAddSalesCoordinator(coordinator._id)
                                }
                              >
                                Add
                              </Button>
                            </td>
                          </tr>
                        ))}
                      </tbody>
                    </table>
                  </div>
                  <div className="d-flex justify-content-between">
                    <div>
                      Showing {modalSalesCoordinators?.length} of{" "}
                      {modalTotalData} entries
                    </div>
                    <div>
                      <button
                        onClick={handlePreviousPage}
                        disabled={modalcurrentPage === 1 || loading}
                        className="btn btn-primary"
                      >
                        Previous
                      </button>
                      <button
                        onClick={handleNextPage}
                        disabled={
                          modalSalesCoordinators?.length < modalitemPerPage ||
                          loading
                        }
                        className="btn btn-primary ml-2"
                      >
                        Next
                      </button>
                    </div>
                  </div>
                </DialogContent>
                <DialogActions>
                  <Button onClick={handleCloseModal} color="secondary">
                    Cancel
                  </Button>
                </DialogActions>
              </Dialog>
            </div>
          </div>

          <div className="row">
            <div className="col-lg-12">
              <div className="card">
                <div className="card-body">
                  <div className="row ml-0 mr-0 mb-10">
                    <div className="col-lg-1">
                      <div className="dataTables_length">
                        <label className="w-100">
                          Show
                          <select
                            onChange={(e) => {
                              setItemPerPage(e.target.value);
                              setCurrentPage(1);
                            }}
                            className="form-control"
                            disabled={loading}
                          >
                            <option value="10">10</option>
                            <option value="25">25</option>
                            <option value="50">50</option>
                            <option value="100">100</option>
                          </select>
                          entries
                        </label>
                      </div>
                    </div>
                    <div className="col-lg-3">
                      <label>Sales Coordinator Name:</label>
                      <input
                        type="text"
                        placeholder="Sales Coordinator name"
                        className="form-control"
                        ref={nameRef}
                        onChange={handleSearchChange}
                        disabled={loading}
                      />
                    </div>
                    <div className="col-lg-3">
                      <label>Mobile Number:</label>
                      <input
                        type="text"
                        placeholder="Mobile Number"
                        className="form-control"
                        ref={mobileRef}
                        onChange={handleSearchChange}
                        disabled={loading}
                      />
                    </div>
                  </div>

                  <div className="table-responsive table-shoot mt-3">
                    <table className="table table-centered table-nowrap">
                      <thead
                        className="thead-light"
                        style={{ background: "#ecdddd" }}
                      >
                        <tr>
                          <th>Unique Id </th>
                          <th className="text-start">Name</th>
                          <th className="text-start">Mobile No.</th>
                          <th className="text-start">Email</th>
                          <th className="text-start">Action</th>
                        </tr>
                      </thead>

                      <tbody>
                        {loading ? (
                          <tr>
                            <td className="text-center" colSpan="6">
                              Loading...
                            </td>
                          </tr>
                        ) : salescoordinatorsData?.length > 0 ? (
                          salescoordinatorsData?.map((salescoordinator, i) => {
                            return (
                              <tr key={i}>
                                <td className="text-start">
                                  {salescoordinator?.uniqueId}
                                </td>
                                <td className="text-start">
                                  {salescoordinator?.name}
                                </td>
                                <td className="text-start">
                                  {salescoordinator?.mobileNumber}
                                </td>
                                <td className="text-start">
                                  {salescoordinator?.email ? (
                                    salescoordinator?.email
                                  ) : (
                                    <small className="m-0 text-secondary">
                                      No Email Added!
                                    </small>
                                  )}
                                </td>
                                <td className="text-start">
                                  {/* <Link
                                    to={`/salescoordinator/edit/${salescoordinator._id}`}
                                  >
                                    <button
                                      style={{
                                        color: "white",
                                        marginRight: "1rem",
                                      }}
                                      type="button"
                                      className="btn btn-info btn-sm  waves-effect waves-light btn-table ml-2"
                                    >
                                      Edit
                                    </button>
                                  </Link> */}

                                  <button
                                    type="button"
                                    style={{ color: "white" }}
                                    className="btn btn-danger btn-sm  waves-effect waves-light btn-table ml-2"
                                    onClick={() =>
                                      handleDelete(salescoordinator._id)
                                    }
                                  >
                                    Delete
                                  </button>
                                </td>
                              </tr>
                            );
                          })
                        ) : (
                          <tr>
                            <td className="text-center" colSpan="6">
                              No Sales Coordinator found!
                            </td>
                          </tr>
                        )}
                      </tbody>
                    </table>
                  </div>
                  <div className="d-flex justify-content-between">
                    <div>
                      Showing {salescoordinatorsData?.length} of {totalData}{" "}
                      entries
                    </div>
                    <div>
                      <button
                        onClick={() => setCurrentPage(currentPage - 1)}
                        disabled={currentPage === 1 || loading}
                        className="btn btn-primary"
                      >
                        Previous
                      </button>
                      <button
                        onClick={() => setCurrentPage(currentPage + 1)}
                        disabled={
                          salescoordinatorsData?.length < itemPerPage || loading
                        }
                        className="btn btn-primary ml-2"
                      >
                        Next
                      </button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default ViewSalesCoOrdinatorTM;
